@@ -4,8 +4,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 require File::Spec::Unix;
 
-$VERSION = '3.58_01';
-$VERSION =~ tr/_//d;
+$VERSION = '3.26';
 
 @ISA = qw(File::Spec::Unix);
 
@@ -92,20 +91,15 @@ from the following list:
     $ENV{'TEMP'}
     C:/temp
 
-If running under taint mode, and if the environment
+Since Perl 5.8.0, if running under taint mode, and if the environment
 variables are tainted, they are not used.
 
 =cut
 
+my $tmpdir;
 sub tmpdir {
-    my $cached = $_[0]->_cached_tmpdir(qw 'TMPDIR TMP TEMP');
-    return $cached if defined $cached;
-    $_[0]->_cache_tmpdir(
-        $_[0]->_tmpdir(
-            $ENV{TMPDIR}, "/tmp", $ENV{'TMP'}, $ENV{'TEMP'}, 'C:/temp'
-        ),
-        qw 'TMPDIR TMP TEMP'
-    );
+    return $tmpdir if defined $tmpdir;
+    $tmpdir = $_[0]->_tmpdir( $ENV{TMPDIR}, "/tmp", $ENV{'TMP'}, $ENV{'TEMP'}, 'C:/temp' );
 }
 
 =item case_tolerant
@@ -117,7 +111,7 @@ Default: 1
 
 =cut
 
-sub case_tolerant {
+sub case_tolerant () {
   return 1 unless $^O eq 'cygwin'
     and defined &Cygwin::mount_flags;
 
