@@ -4,7 +4,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 require File::Spec::Unix;
 
-$VERSION = '1.4';
+$VERSION = '3.26';
 
 @ISA = qw(File::Spec::Unix);
 
@@ -53,7 +53,7 @@ done in MacPerl's environment and helps to distinguish a file path from a
 directory path.
 
 B<IMPORTANT NOTE:> Beginning with version 1.3 of this module, the resulting
-path is relative by default and I<not> absolute. This descision was made due
+path is relative by default and I<not> absolute. This decision was made due
 to portability reasons. Since C<File::Spec-E<gt>catdir()> returns relative paths
 on all other operating systems, it will now also follow this convention on Mac
 OS. Note that this may break some existing scripts.
@@ -272,7 +272,7 @@ by default, but can be forced to be absolute (but avoid this).
 
 B<IMPORTANT NOTE:> Beginning with version 1.3 of this module, the
 resulting path is relative by default and I<not> absolute. This
-descision was made due to portability reasons. Since
+decision was made due to portability reasons. Since
 C<File::Spec-E<gt>catfile()> returns relative paths on all other
 operating systems, it will now also follow this convention on Mac OS.
 Note that this may break some existing scripts.
@@ -530,7 +530,7 @@ sub splitdir {
 	my @result = ();
 	my ($head, $sep, $tail, $volume, $directories);
 
-	return ('') if ( (!defined($path)) || ($path eq '') );
+	return @result if ( (!defined($path)) || ($path eq '') );
 	return (':') if ($path eq ':');
 
 	( $volume, $sep, $directories ) = $path =~ m|^((?:[^:]+:)?)(:*)(.*)|s;
